# -*- coding: utf-8 -*-

LOGGER_NAME = 'gourd'

BACKLOG = 65535

# 仅对 tcpserver 有效
TERMINATOR = '\n'

# 仅对 udpserver 有效
PACKAGE_SIZE = 64 * 1024    # 64K

# 系统返回码
RET_SYSTEM = -9999

# 非debug，异常时的返回
ERROR_INTERNAL = u'internal error'

# 每次loop的超时
POLL_TIMEOUT = 10.0